==> zn-plugin-workflow-0.1.5.tgz: package/web/src/component/instance/FlowStep.js <==
var React = require('react');

module.exports = React.createClass({
	__renderSchemaFormData: function (data){
		console.log(data);
		if(data){
			var _data = JSON.parse(data);
			return <zn.react.Group title="自定义表单" className="schema-form-data" >
				<ul>
					{
						Object.keys(_data).map(function (key){
							return <li className="item">
								<div className="key">{key}</div>
								<div className="value">{_data[key]}</div>
							</li>;
						})
					}
				</ul>
			</zn.react.Group>;
		}else {
			return null;
		}
	},
	__renderFiles: function (files){
		return <div>{files}</div>;
	},
	render:function(){
		return (
			<div className="zn-plugin-workflow-instance-flow-step zn-plugin-workflow-panel" >
				<div className="title">
					<span>当前状态：{this.props.current.zn_title}</span>
				</div>
				<div className="content">
					<ul className="steps">
						{
							this.props.data.map(function (value){
								if(value.type=='end'){
									value.state = 2;
								}
								return <li className={"step state-" + value.state + ' type-' + value.type}>
									<div className="title">{value.zn_title}</div>
									<div className="dot"><i className={'fa ' + (value.state==1?'fa-pencil-square-o':'fa-check')} /></div>
									<div className="detail">
										<div className="user">{value.zn_modify_user || '☆☆☆'}</div>
										<div className="time">{value.zn_modify_time || value.zn_create_time}</div>
									</div>
								</li>;
							})
						}
					</ul>
					<ul className="steps-detail">
						{
							this.props.data.map(function (value){
								if(value.state==1 || value.type == 'end'){
									return null;
								}

								return <li className={"step state-" + value.state + ' type-' + value.type}>
									<div className="step-header">
										<span>[ {value.zn_modify_user} ] {value.zn_title}</span>
										<span>{value.zn_modify_time || value.zn_create_time}</span>
									</div>
									<div className="step-content">
										{this.__renderSchemaFormData(value.schema_form_data)}
										<div className="note">{value.zn_note}</div>
										<div className="files">
											<div className="title">附件</div>
											{this.__renderFiles(value.files)}
										</div>
									</div>
								</li>;
							}.bind(this))
						}
					</ul>
				</div>
			</div>
		);
	}
});

==> zn-plugin-workflow-0.1.14.tgz: package/web/src/component/instance/FlowStep.js <==
var React = require('react');

module.exports = React.createClass({
	__renderSchemaFormData: function (data){
		console.log(data);
		if(data){
			var _data = JSON.parse(data);
			return <zn.react.Group title="自定义表单" className="schema-form-data" >
				<ul>
					{
						Object.keys(_data).map(function (key){
							return <li className="item">
								<div className="key">{key}</div>
								<div className="value">{_data[key]}</div>
							</li>;
						})
					}
				</ul>
			</zn.react.Group>;
		}else {
			return null;
		}
	},
	render:function(){
		return (
			<div className="zn-plugin-workflow-instance-flow-step zn-plugin-workflow-panel" >
				<div className="title">
					<span>当前状态：{this.props.current.zn_title}</span>
				</div>
				<div className="content">
					<ul className="steps">
						{
							this.props.data.map(function (value){
								if(value.type=='end'){
									value.state = 2;
								}
								return <li className={"step state-" + value.state + ' type-' + value.type}>
									<div className="title">{value.zn_title}</div>
									<div className="dot"><i className={'fa ' + (value.state==1?'fa-pencil-square-o':'fa-check')} /></div>
									<div className="detail">
										<div className="user">{value.zn_modify_user || '☆☆☆'}</div>
										<div className="time">{value.zn_modify_time || value.zn_create_time}</div>
									</div>
								</li>;
							})
						}
					</ul>
					<ul className="steps-detail">
						{
							this.props.data.map(function (value){
								if(value.state==1 || value.type == 'end'){
									return null;
								}

								return <li className={"step state-" + value.state + ' type-' + value.type}>
									<div className="step-header">
										<span>[ {value.zn_modify_user} ] {value.zn_title}</span>
										<span>{value.zn_modify_time || value.zn_create_time}</span>
									</div>
									<div className="step-content">
										{this.__renderSchemaFormData(value.schema_form_data)}
										<div className="note">{value.zn_note}</div>
										<div className="files">
											<div className="title">附件：</div>
											<zn.react.Files value={value.files} />
										</div>
									</div>
								</li>;
							}.bind(this))
						}
					</ul>
				</div>
			</div>
		);
	}
});
